Transports
==========

.. automodule:: cumin.transports
   :exclude-members: Command,State

    .. autoclass:: Command
       :special-members: __repr__,__str__,__eq__,__ne__

    .. autoclass:: State
       :special-members: __repr__,__str__,__getattr__,__cmp__

.. rubric:: Available transports

.. toctree::

   cumin.transports.clustershell
